@@ -14,8 +14,9 @@ modules = [
     "2chen",
     "35photo",
     "3dbooru",
-    "420chan",
     "4chan",
+    "4archive",
+    "4chanarchives",
     "500px",
     "8chan",
     "8muses",
@@ -24,11 +25,11 @@ modules = [
     "artstation",
     "aryion",
     "bbc",
-    "bcy",
     "behance",
     "blogger",
     "bunkr",
     "catbox",
+    "chevereto",
     "comicvine",
     "cyberdrop",
     "danbooru",
@@ -50,7 +51,6 @@ modules = [
     "gelbooru",
     "gelbooru_v01",
     "gelbooru_v02",
-    "gfycat",
     "gofile",
     "hbrowse",
     "hentai2read",
@@ -75,14 +75,15 @@ modules = [
     "issuu",
     "itaku",
     "itchio",
+    "jschan",
     "kabeuchi",
     "keenspot",
     "kemonoparty",
     "khinsider",
     "komikcast",
+    "lensdump",
     "lexica",
     "lightroom",
-    "lineblog",
     "livedoor",
     "luscious",
     "lynxchan",
@@ -92,12 +93,12 @@ modules = [
     "mangakakalot",
     "manganelo",
     "mangapark",
+    "mangaread",
     "mangasee",
     "mangoxo",
     "misskey",
     "myhentaigallery",
     "myportfolio",
-    "nana",
     "naver",
     "naverwebtoon",
     "newgrounds",
@@ -116,12 +117,14 @@ modules = [
     "piczel",
     "pillowfort",
     "pinterest",
+    "pixeldrain",
     "pixiv",
     "pixnet",
     "plurk",
     "poipiku",
     "pornhub",
     "pornpics",
+    "postmill",
     "pururin",
     "reactor",
     "readcomiconline",
@@ -146,12 +149,14 @@ modules = [
     "tapas",
     "tcbscans",
     "telegraph",
+    "tmohentai",
     "toyhouse",
     "tsumino",
     "tumblr",
     "tumblrgallery",
     "twibooru",
     "twitter",
+    "urlgalleries",
     "unsplash",
     "uploadir",
     "urlshortener",
