@@ -8,32 +8,25 @@
 
 """Extractors for Blogger blogs"""
 
-from .common import Extractor, Message
+from .common import BaseExtractor, Message
 from .. import text, util
 import re
 
-BASE_PATTERN = (
-    r"(?:blogger:(?:https?://)?([^/]+)|"
-    r"(?:https?://)?([\w-]+\.blogspot\.com))")
 
-
-class BloggerExtractor(Extractor):
+class BloggerExtractor(BaseExtractor):
     """Base class for blogger extractors"""
-    category = "blogger"
-    directory_fmt = ("{category}", "{blog[name]}",
+    basecategory = "blogger"
+    directory_fmt = ("blogger", "{blog[name]}",
                      "{post[date]:%Y-%m-%d} {post[title]}")
     filename_fmt = "{num:>03}.{extension}"
     archive_fmt = "{post[id]}_{num}"
-    root = "https://www.blogger.com"
 
-    def __init__(self, match):
-        Extractor.__init__(self, match)
-        self.videos = self.config("videos", True)
-        self.blog = match.group(1) or match.group(2)
+    def _init(self):
         self.api = BloggerAPI(self)
+        self.blog = self.root.rpartition("/")[2]
+        self.videos = self.config("videos", True)
 
     def items(self):
-
         blog = self.api.blog_by_url("http://" + self.blog)
         blog["pages"] = blog["pages"]["totalItems"]
         blog["posts"] = blog["posts"]["totalItems"]
@@ -44,6 +37,7 @@ class BloggerExtractor(Extractor):
         findall_image = re.compile(
             r'src="(https?://(?:'
             r'blogger\.googleusercontent\.com/img|'
+            r'lh\d+\.googleusercontent\.com/|'
             r'\d+\.bp\.blogspot\.com)/[^"]+)').findall
         findall_video = re.compile(
             r'src="(https?://www\.blogger\.com/video\.g\?token=[^"]+)').findall
@@ -90,66 +84,27 @@ class BloggerExtractor(Extractor):
         """Return additional metadata"""
 
 
+BASE_PATTERN = BloggerExtractor.update({
+    "blogspot": {
+        "root": None,
+        "pattern": r"[\w-]+\.blogspot\.com",
+    },
+    "micmicidol": {
+        "root": "https://www.micmicidol.club",
+        "pattern": r"(?:www\.)?micmicidol\.club",
+    },
+})
+
+
 class BloggerPostExtractor(BloggerExtractor):
     """Extractor for a single blog post"""
     subcategory = "post"
-    pattern = BASE_PATTERN + r"(/\d{4}/\d\d/[^/?#]+\.html)"
-    test = (
-        ("https://julianbphotography.blogspot.com/2010/12/moon-rise.html", {
-            "url": "9928429fb62f712eb4de80f53625eccecc614aae",
-            "pattern": r"https://3.bp.blogspot.com/.*/s0/Icy-Moonrise-.*.jpg",
-            "keyword": {
-                "blog": {
-                    "date"       : "dt:2010-11-21 18:19:42",
-                    "description": "",
-                    "id"         : "5623928067739466034",
-                    "kind"       : "blogger#blog",
-                    "locale"     : dict,
-                    "name"       : "Julian Bunker Photography",
-                    "pages"      : int,
-                    "posts"      : int,
-                    "published"  : "2010-11-21T10:19:42-08:00",
-                    "updated"    : str,
-                    "url"        : "http://julianbphotography.blogspot.com/",
-                },
-                "post": {
-                    "author"     : "Julian Bunker",
-                    "content"    : str,
-                    "date"       : "dt:2010-12-26 01:08:00",
-                    "etag"       : str,
-                    "id"         : "6955139236418998998",
-                    "kind"       : "blogger#post",
-                    "published"  : "2010-12-25T17:08:00-08:00",
-                    "replies"    : "0",
-                    "title"      : "Moon Rise",
-                    "updated"    : "2011-12-06T05:21:24-08:00",
-                    "url"        : "re:.+/2010/12/moon-rise.html$",
-                },
-                "num": int,
-                "url": str,
-            },
-        }),
-        ("blogger:http://www.julianbunker.com/2010/12/moon-rise.html"),
-        # video (#587)
-        (("http://cfnmscenesinmovies.blogspot.com/2011/11/"
-          "cfnm-scene-jenna-fischer-in-office.html"), {
-            "pattern": r"https://.+\.googlevideo\.com/videoplayback",
-        }),
-        # image URLs with width/height (#1061)
-        #  ("https://aaaninja.blogspot.com/2020/08/altera-boob-press-2.html", {
-        #      "pattern": r"https://1.bp.blogspot.com/.+/s0/altera_.+png",
-        #  }),
-        # new image domain (#2204)
-        (("https://randomthingsthroughmyletterbox.blogspot.com/2022/01"
-          "/bitter-flowers-by-gunnar-staalesen-blog.html"), {
-            "pattern": r"https://blogger.googleusercontent.com/img/a/.+=s0$",
-            "count": 8,
-        }),
-    )
+    pattern = BASE_PATTERN + r"(/\d\d\d\d/\d\d/[^/?#]+\.html)"
+    example = "https://BLOG.blogspot.com/1970/01/TITLE.html"
 
     def __init__(self, match):
         BloggerExtractor.__init__(self, match)
-        self.path = match.group(3)
+        self.path = match.group(match.lastindex)
 
     def posts(self, blog):
         return (self.api.post_by_path(blog["id"], self.path),)
@@ -159,17 +114,7 @@ class BloggerBlogExtractor(BloggerExtractor):
     """Extractor for an entire Blogger blog"""
     subcategory = "blog"
     pattern = BASE_PATTERN + r"/?$"
-    test = (
-        ("https://julianbphotography.blogspot.com/", {
-            "range": "1-25",
-            "count": 25,
-            "pattern": r"https://\d\.bp\.blogspot\.com/.*/s0/[^.]+\.jpg",
-        }),
-        ("blogger:https://www.kefblog.com.ng/", {
-            "range": "1-25",
-            "count": 25,
-        }),
-    )
+    example = "https://BLOG.blogspot.com/"
 
     def posts(self, blog):
         return self.api.blog_posts(blog["id"])
@@ -179,16 +124,11 @@ class BloggerSearchExtractor(BloggerExtractor):
     """Extractor for Blogger search resuls"""
     subcategory = "search"
     pattern = BASE_PATTERN + r"/search/?\?q=([^&#]+)"
-    test = (
-        ("https://julianbphotography.blogspot.com/search?q=400mm", {
-            "count": "< 10",
-            "keyword": {"query": "400mm"},
-        }),
-    )
+    example = "https://BLOG.blogspot.com/search?q=QUERY"
 
     def __init__(self, match):
         BloggerExtractor.__init__(self, match)
-        self.query = text.unquote(match.group(3))
+        self.query = text.unquote(match.group(match.lastindex))
 
     def posts(self, blog):
         return self.api.blog_search(blog["id"], self.query)
@@ -201,17 +141,11 @@ class BloggerLabelExtractor(BloggerExtractor):
     """Extractor for Blogger posts by label"""
     subcategory = "label"
     pattern = BASE_PATTERN + r"/search/label/([^/?#]+)"
-    test = (
-        ("https://dmmagazine.blogspot.com/search/label/D%26D", {
-            "range": "1-25",
-            "count": 25,
-            "keyword": {"label": "D&D"},
-        }),
-    )
+    example = "https://BLOG.blogspot.com/search/label/LABEL"
 
     def __init__(self, match):
         BloggerExtractor.__init__(self, match)
-        self.label = text.unquote(match.group(3))
+        self.label = text.unquote(match.group(match.lastindex))
 
     def posts(self, blog):
         return self.api.blog_posts(blog["id"], self.label)
