@@ -42,12 +42,13 @@ class DeviantartExtractor(Extractor):
         self.offset = 0
 
     def _init(self):
-        self.jwt = self.config("jwt", True)
+        self.jwt = self.config("jwt", False)
         self.flat = self.config("flat", True)
         self.extra = self.config("extra", False)
         self.quality = self.config("quality", "100")
         self.original = self.config("original", True)
         self.comments = self.config("comments", False)
+        self.intermediary = self.config("intermediary", True)
 
         self.api = DeviantartOAuthAPI(self)
         self.group = False
@@ -91,14 +92,20 @@ class DeviantartExtractor(Extractor):
             return True
 
     def items(self):
-        if self.user and self.config("group", True):
-            profile = self.api.user_profile(self.user)
-            self.group = not profile
-            if self.group:
-                self.subcategory = "group-" + self.subcategory
-                self.user = self.user.lower()
-            else:
-                self.user = profile["user"]["username"]
+        if self.user:
+            group = self.config("group", True)
+            if group:
+                profile = self.api.user_profile(self.user)
+                if profile:
+                    self.user = profile["user"]["username"]
+                    self.group = False
+                elif group == "skip":
+                    self.log.info("Skipping group '%s'", self.user)
+                    raise exception.StopExtraction()
+                else:
+                    self.subcategory = "group-" + self.subcategory
+                    self.user = self.user.lower()
+                    self.group = True
 
         for deviation in self.deviations():
             if isinstance(deviation, tuple):
@@ -130,12 +137,13 @@ class DeviantartExtractor(Extractor):
                 elif self.jwt:
                     self._update_token(deviation, content)
                 elif content["src"].startswith("https://images-wixmp-"):
-                    if deviation["index"] <= 790677560:
+                    if self.intermediary and deviation["index"] <= 790677560:
                         # https://github.com/r888888888/danbooru/issues/4069
                         intermediary, count = re.subn(
                             r"(/f/[^/]+/[^/]+)/v\d+/.*",
                             r"/intermediary\1", content["src"], 1)
                         if count:
+                            deviation["is_original"] = False
                             deviation["_fallback"] = (content["src"],)
                             content["src"] = intermediary
                     if self.quality:
@@ -228,7 +236,7 @@ class DeviantartExtractor(Extractor):
 
         if self.comments:
             deviation["comments"] = (
-                self.api.comments(deviation["deviationid"], target="deviation")
+                self._extract_comments(deviation["deviationid"], "deviation")
                 if deviation["stats"]["comments"] else ()
             )
 
@@ -395,6 +403,28 @@ class DeviantartExtractor(Extractor):
                 binascii.b2a_base64(payload).rstrip(b"=\n").decode())
         )
 
+    def _extract_comments(self, target_id, target_type="deviation"):
+        results = None
+        comment_ids = [None]
+
+        while comment_ids:
+            comments = self.api.comments(
+                target_id, target_type, comment_ids.pop())
+
+            if results:
+                results.extend(comments)
+            else:
+                results = comments
+
+            # parent comments, i.e. nodes with at least one child
+            parents = {c["parentid"] for c in comments}
+            # comments with more than one reply
+            replies = {c["commentid"] for c in comments if c["replies"]}
+            # add comment UUIDs with replies that are not parent to any node
+            comment_ids.extend(replies - parents)
+
+        return results
+
     def _limited_request(self, url, **kwargs):
         """Limits HTTP requests to one every 2 seconds"""
         kwargs["fatal"] = None
@@ -698,7 +728,7 @@ class DeviantartStatusExtractor(DeviantartExtractor):
         deviation["stats"] = {"comments": comments_count}
         if self.comments:
             deviation["comments"] = (
-                self.api.comments(deviation["statusid"], target="status")
+                self._extract_comments(deviation["statusid"], "status")
                 if comments_count else ()
             )
 
@@ -975,8 +1005,9 @@ class DeviantartOAuthAPI():
         self.strategy = extractor.config("pagination")
         self.public = extractor.config("public", True)
 
-        self.client_id = extractor.config("client-id")
-        if self.client_id:
+        client_id = extractor.config("client-id")
+        if client_id:
+            self.client_id = str(client_id)
             self.client_secret = extractor.config("client-secret")
         else:
             self.client_id = self.CLIENT_ID
@@ -984,7 +1015,7 @@ class DeviantartOAuthAPI():
 
         token = extractor.config("refresh-token")
         if token is None or token == "cache":
-            token = "#" + str(self.client_id)
+            token = "#" + self.client_id
             if not _refresh_token_cache(token):
                 token = None
         self.refresh_token_key = token
@@ -1072,11 +1103,17 @@ class DeviantartOAuthAPI():
                   "mature_content": self.mature}
         return self._pagination_list(endpoint, params)
 
-    def comments(self, id, target, offset=0):
+    def comments(self, target_id, target_type="deviation",
+                 comment_id=None, offset=0):
         """Fetch comments posted on a target"""
-        endpoint = "/comments/{}/{}".format(target, id)
-        params = {"maxdepth": "5", "offset": offset, "limit": 50,
-                  "mature_content": self.mature}
+        endpoint = "/comments/{}/{}".format(target_type, target_id)
+        params = {
+            "commentid"     : comment_id,
+            "maxdepth"      : "5",
+            "offset"        : offset,
+            "limit"         : 50,
+            "mature_content": self.mature,
+        }
         return self._pagination_list(endpoint, params=params, key="thread")
 
     def deviation(self, deviation_id, public=None):
@@ -1205,7 +1242,7 @@ class DeviantartOAuthAPI():
             self.log.info("Requesting public access token")
             data = {"grant_type": "client_credentials"}
 
-        auth = (self.client_id, self.client_secret)
+        auth = util.HTTPBasicAuth(self.client_id, self.client_secret)
         response = self.extractor.request(
             url, method="POST", data=data, auth=auth, fatal=False)
         data = response.json()
@@ -1544,7 +1581,7 @@ class DeviantartEclipseAPI():
         return token
 
 
-@cache(maxage=100*365*86400, keyarg=0)
+@cache(maxage=36500*86400, keyarg=0)
 def _refresh_token_cache(token):
     if token and token[0] == "#":
         return None
