@@ -10,7 +10,6 @@
 
 from .common import Extractor, Message
 from .. import text, util, exception
-from ..cache import cache
 import itertools
 
 BASE_PATTERN = r"(?:https?://)?(?:\w+\.)?pinterest\.[\w.]+"
@@ -23,19 +22,16 @@ class PinterestExtractor(Extractor):
     archive_fmt = "{id}{media_id}"
     root = "https://www.pinterest.com"
 
-    def __init__(self, match):
-        Extractor.__init__(self, match)
-
+    def _init(self):
         domain = self.config("domain")
         if not domain or domain == "auto" :
-            self.root = text.root_from_url(match.group(0))
+            self.root = text.root_from_url(self.url)
         else:
             self.root = text.ensure_http_scheme(domain)
 
         self.api = PinterestAPI(self)
 
     def items(self):
-        self.api.login()
         data = self.metadata()
         videos = self.config("videos", True)
 
@@ -112,22 +108,8 @@ class PinterestExtractor(Extractor):
 class PinterestPinExtractor(PinterestExtractor):
     """Extractor for images from a single pin from pinterest.com"""
     subcategory = "pin"
-    pattern = BASE_PATTERN + r"/pin/([^/?#&]+)(?!.*#related$)"
-    test = (
-        ("https://www.pinterest.com/pin/858146903966145189/", {
-            "url": "afb3c26719e3a530bb0e871c480882a801a4e8a5",
-            "content": ("4c435a66f6bb82bb681db2ecc888f76cf6c5f9ca",
-                        "d3e24bc9f7af585e8c23b9136956bd45a4d9b947"),
-        }),
-        # video pin (#1189)
-        ("https://www.pinterest.com/pin/422564377542934214/", {
-            "pattern": r"https://v\.pinimg\.com/videos/mc/hls/d7/22/ff"
-                       r"/d722ff00ab2352981b89974b37909de8.m3u8",
-        }),
-        ("https://www.pinterest.com/pin/858146903966145188/", {
-            "exception": exception.NotFoundError,
-        }),
-    )
+    pattern = BASE_PATTERN + r"/pin/([^/?#]+)(?!.*#related$)"
+    example = "https://www.pinterest.com/pin/12345/"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -147,28 +129,9 @@ class PinterestBoardExtractor(PinterestExtractor):
     subcategory = "board"
     directory_fmt = ("{category}", "{board[owner][username]}", "{board[name]}")
     archive_fmt = "{board[id]}_{id}"
-    pattern = (BASE_PATTERN + r"/(?!pin/)([^/?#&]+)"
-               "/(?!_saved|_created|pins/)([^/?#&]+)/?$")
-    test = (
-        ("https://www.pinterest.com/g1952849/test-/", {
-            "pattern": r"https://i\.pinimg\.com/originals/",
-            "count": 2,
-        }),
-        # board with sections (#835)
-        ("https://www.pinterest.com/g1952849/stuff/", {
-            "options": (("sections", True),),
-            "count": 4,
-        }),
-        # secret board (#1055)
-        ("https://www.pinterest.de/g1952849/secret/", {
-            "count": 2,
-        }),
-        ("https://www.pinterest.com/g1952848/test/", {
-            "exception": exception.GalleryDLException,
-        }),
-        # .co.uk TLD (#914)
-        ("https://www.pinterest.co.uk/hextra7519/based-animals/"),
-    )
+    pattern = (BASE_PATTERN + r"/(?!pin/)([^/?#]+)"
+               "/(?!_saved|_created|pins/)([^/?#]+)/?$")
+    example = "https://www.pinterest.com/USER/BOARD/"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -198,14 +161,8 @@ class PinterestBoardExtractor(PinterestExtractor):
 class PinterestUserExtractor(PinterestExtractor):
     """Extractor for a user's boards"""
     subcategory = "user"
-    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#&]+)(?:/_saved)?/?$"
-    test = (
-        ("https://www.pinterest.com/g1952849/", {
-            "pattern": PinterestBoardExtractor.pattern,
-            "count": ">= 2",
-        }),
-        ("https://www.pinterest.com/g1952849/_saved/"),
-    )
+    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#]+)(?:/_saved)?/?$"
+    example = "https://www.pinterest.com/USER/"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -223,12 +180,8 @@ class PinterestAllpinsExtractor(PinterestExtractor):
     """Extractor for a user's 'All Pins' feed"""
     subcategory = "allpins"
     directory_fmt = ("{category}", "{user}")
-    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#&]+)/pins/?$"
-    test = ("https://www.pinterest.com/g1952849/pins/", {
-        "pattern": r"https://i\.pinimg\.com/originals/[0-9a-f]{2}"
-                   r"/[0-9a-f]{2}/[0-9a-f]{2}/[0-9a-f]{32}\.\w{3}",
-        "count": 7,
-    })
+    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#]+)/pins/?$"
+    example = "https://www.pinterest.com/USER/pins/"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -245,13 +198,8 @@ class PinterestCreatedExtractor(PinterestExtractor):
     """Extractor for a user's created pins"""
     subcategory = "created"
     directory_fmt = ("{category}", "{user}")
-    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#&]+)/_created/?$"
-    test = ("https://www.pinterest.de/digitalmomblog/_created/", {
-        "pattern": r"https://i\.pinimg\.com/originals/[0-9a-f]{2}"
-                   r"/[0-9a-f]{2}/[0-9a-f]{2}/[0-9a-f]{32}\.jpg",
-        "count": 10,
-        "range": "1-10",
-    })
+    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#]+)/_created/?$"
+    example = "https://www.pinterest.com/USER/_created/"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -270,10 +218,8 @@ class PinterestSectionExtractor(PinterestExtractor):
     directory_fmt = ("{category}", "{board[owner][username]}",
                      "{board[name]}", "{section[title]}")
     archive_fmt = "{board[id]}_{id}"
-    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#&]+)/([^/?#&]+)/([^/?#&]+)"
-    test = ("https://www.pinterest.com/g1952849/stuff/section", {
-        "count": 2,
-    })
+    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#]+)/([^/?#]+)/([^/?#]+)"
+    example = "https://www.pinterest.com/USER/BOARD/SEcTION"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -301,10 +247,7 @@ class PinterestSearchExtractor(PinterestExtractor):
     subcategory = "search"
     directory_fmt = ("{category}", "Search", "{search}")
     pattern = BASE_PATTERN + r"/search/pins/?\?q=([^&#]+)"
-    test = ("https://www.pinterest.com/search/pins/?q=nature", {
-        "range": "1-50",
-        "count": ">= 50",
-    })
+    example = "https://www.pinterest.com/search/pins/?q=QUERY"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
@@ -321,12 +264,8 @@ class PinterestRelatedPinExtractor(PinterestPinExtractor):
     """Extractor for related pins of another pin from pinterest.com"""
     subcategory = "related-pin"
     directory_fmt = ("{category}", "related {original_pin[id]}")
-    pattern = BASE_PATTERN + r"/pin/([^/?#&]+).*#related$"
-    test = ("https://www.pinterest.com/pin/858146903966145189/#related", {
-        "range": "31-70",
-        "count": 40,
-        "archive": False,
-    })
+    pattern = BASE_PATTERN + r"/pin/([^/?#]+).*#related$"
+    example = "https://www.pinterest.com/pin/12345/#related"
 
     def metadata(self):
         return {"original_pin": self.api.pin(self.pin_id)}
@@ -340,37 +279,25 @@ class PinterestRelatedBoardExtractor(PinterestBoardExtractor):
     subcategory = "related-board"
     directory_fmt = ("{category}", "{board[owner][username]}",
                      "{board[name]}", "related")
-    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#&]+)/([^/?#&]+)/?#related$"
-    test = ("https://www.pinterest.com/g1952849/test-/#related", {
-        "range": "31-70",
-        "count": 40,
-        "archive": False,
-    })
+    pattern = BASE_PATTERN + r"/(?!pin/)([^/?#]+)/([^/?#]+)/?#related$"
+    example = "https://www.pinterest.com/USER/BOARD/#related"
 
     def pins(self):
-        return self.api.board_related(self.board["id"])
+        return self.api.board_content_recommendation(self.board["id"])
 
 
 class PinterestPinitExtractor(PinterestExtractor):
     """Extractor for images from a pin.it URL"""
     subcategory = "pinit"
-    pattern = r"(?:https?://)?pin\.it/([^/?#&]+)"
-
-    test = (
-        ("https://pin.it/Hvt8hgT", {
-            "url": "8daad8558382c68f0868bdbd17d05205184632fa",
-        }),
-        ("https://pin.it/Hvt8hgS", {
-            "exception": exception.NotFoundError,
-        }),
-    )
+    pattern = r"(?:https?://)?pin\.it/([^/?#]+)"
+    example = "https://pin.it/abcde"
 
     def __init__(self, match):
         PinterestExtractor.__init__(self, match)
         self.shortened_id = match.group(1)
 
     def items(self):
-        url = "https://api.pinterest.com/url_shortener/{}/redirect".format(
+        url = "https://api.pinterest.com/url_shortener/{}/redirect/".format(
             self.shortened_id)
         response = self.request(url, method="HEAD", allow_redirects=False)
         location = response.headers.get("Location")
@@ -396,7 +323,6 @@ class PinterestAPI():
             "Accept"              : "application/json, text/javascript, "
                                     "*/*, q=0.01",
             "Accept-Language"     : "en-US,en;q=0.5",
-            "Referer"             : self.root + "/",
             "X-Requested-With"    : "XMLHttpRequest",
             "X-APP-VERSION"       : "0c4af40",
             "X-CSRFToken"         : csrf_token,
@@ -458,10 +384,10 @@ class PinterestAPI():
         options = {"section_id": section_id}
         return self._pagination("BoardSectionPins", options)
 
-    def board_related(self, board_id):
+    def board_content_recommendation(self, board_id):
         """Yield related pins of a specific board"""
-        options = {"board_id": board_id, "add_vase": True}
-        return self._pagination("BoardRelatedPixieFeed", options)
+        options = {"id": board_id, "type": "board", "add_vase": True}
+        return self._pagination("BoardContentRecommendation", options)
 
     def user_pins(self, user):
         """Yield all pins from 'user'"""
@@ -488,41 +414,6 @@ class PinterestAPI():
         options = {"query": query, "scope": "pins", "rs": "typed"}
         return self._pagination("BaseSearch", options)
 
-    def login(self):
-        """Login and obtain session cookies"""
-        username, password = self.extractor._get_auth_info()
-        if username:
-            self.cookies.update(self._login_impl(username, password))
-
-    @cache(maxage=180*24*3600, keyarg=1)
-    def _login_impl(self, username, password):
-        self.extractor.log.info("Logging in as %s", username)
-
-        url = self.root + "/resource/UserSessionResource/create/"
-        options = {
-            "username_or_email": username,
-            "password"         : password,
-        }
-        data = {
-            "data"      : util.json_dumps({"options": options}),
-            "source_url": "",
-        }
-
-        try:
-            response = self.extractor.request(
-                url, method="POST", headers=self.headers,
-                cookies=self.cookies, data=data)
-            resource = response.json()["resource_response"]
-        except (exception.HttpError, ValueError, KeyError):
-            raise exception.AuthenticationError()
-
-        if resource["status"] != "success":
-            raise exception.AuthenticationError()
-        return {
-            cookie.name: cookie.value
-            for cookie in response.cookies
-        }
-
     def _call(self, resource, options):
         url = "{}/resource/{}Resource/get/".format(self.root, resource)
         params = {
